package com.steerinfo.dil.controller;

import com.steerinfo.dil.mapper.UniversalMapper;
import com.steerinfo.dil.service.impl.UniversalServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/10/19 18:06
 * 通用接口
 */
@RequestMapping("${api.version}/uc")
@RestController
public class UniversalController extends BaseRESTfulController {

    @Autowired
    UniversalServiceImpl selfServiceMachineService;

    @Autowired
    UniversalMapper universalMapper;

    @Autowired
    ColumnDataUtil columnDataUtil;


    @ApiOperation(value="查询数据打印提货单接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输订单号", required = false, dataType = "Map"),
    })
    @PostMapping("/printTHD")
    public RESTfulResult printTiHuoDan(@RequestBody(required=false) Map<String, Object> mapValue){
        Map<String, Object> tiHuoDan = selfServiceMachineService.printTiHuoDan((String) mapValue.get("orderNumber"));
        return success(tiHuoDan);
    }

    @ApiModelProperty(value = "模糊查询物资")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "244", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/queryMaterialByLike")
    public RESTfulResult queryMaterialByLike(@RequestBody(required = false) Map<String,Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId,
                                           String index) {

        if(mapValue == null) {
            mapValue = new HashMap<>();
        }
        if(index != null){
            mapValue.put("index", index + "%");
        }else {
            mapValue.put("index", "aaaaa%");
        }
        List<Map<String, Object>> list = universalMapper.queryMaterialByLike(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = universalMapper.queryMaterialByLike(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    @ApiModelProperty(value = "模糊查询发货单位")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "247", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/querySupplierByLike")
    public RESTfulResult querySupplierByLike(@RequestBody(required = false) Map<String,Object> mapValue,
                                             Integer pageNum,
                                             Integer pageSize,
                                             Integer apiId,
                                             String index) {
        if(mapValue == null) {
            mapValue = new HashMap<>();
        }
        if(index != null){
            mapValue.put("index", index + "%");
        }else {
            mapValue.put("index", "aaaaa%");
        }
        List<Map<String, Object>> list = universalMapper.querySupplierByLike(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = universalMapper.querySupplierByLike(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    @ApiOperation(value="查询所有空闲的运力信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(248)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllCapacityByCarrierLike")
    public RESTfulResult getAllCapacityByCarrierLike(@RequestBody(required=false) Map<String,Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        String index
    ){
        if(mapValue == null){
            mapValue = new HashMap<>();
        }
        if(index != null){
            mapValue.put("index", index + "%");
        }else {
            mapValue.put("index", "aaaaaa%");
        }
        //不分页筛选数据
        List<Map<String, Object>> allCapacity = universalMapper.getAllCapacityByCarrierLike(mapValue);
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> capacity = universalMapper.getAllCapacityByCarrierLike(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, allCapacity,capacity);
        return success(pageList);
    }
}
